require_relative "player"
require_relative "die"
require_relative "game_turn"
require_relative "treasure_trove"

module StudioGame
class Game
  attr_reader :title
  def initialize(title)
    @title = title.capitalize
    @players = []
  end
  
  def load_players(file_name)
    File.readlines(file_name).each do |line|
      add_player(Player.from_csv(line))
    end
  end
  
  def save_high_scores(file_name="high_scores.txt")
    File.open(file_name, "w") do |file|
      file.puts "#{@title} High Scores:"
      @players.sort.each do |player|
        file.puts high_score_entry(player)
      end
    end
  end
  
  def high_score_entry(player)        
      format_var = player.name.ljust(20, ".")
      "#{format_var}#{player.score}"
  end
  
  def add_player(name)
    @players << name
  end
  
  def player_name_and_health(player)
    puts "\t#{player.name} (#{player.health})"
  end
  
   def total_points
     @players.reduce(0) { |sum, player| sum + player.points }
   end
  
  def print_stats
    strong, wimpy = @players.partition { |player| player.strong? }
    
    puts "\n#{@title} Statistics:"
    puts "\n #{strong.size} Strong Player(s):"
    strong.each do |name|
      player_name_and_health(name)
    end
    
    puts "\n #{wimpy.size} Wimpy Player(s):"
    wimpy.each do |name|
       player_name_and_health(name)
    end
     
     puts "\n#{@title} High Scores:"
     @players.sort.each do |player|
       puts high_score_entry(player)
     end
     
     @players.each do |player|
       puts "\n#{player.name}'s point totals:"
       player.each_treasure do |treasure| 
         puts "#{treasure.points} total #{treasure.name} points"
       end
       
       puts "#{player.points} grand total points"
     end
     puts "\n#{total_points} total points from treasures found" 
  end
  
  def play(rounds)
    puts "\nThere are #{@players.size} player(s)."
    @players.each do |player| 
      puts player
    end
    
    treasures =TreasureTrove::TREASURES
    puts "\nThere are #{treasures.size} treasures to be found:"
    treasures.each do |treasure|
      puts "A #{treasure.name} is worth #{treasure.points} points"
    end

    1.upto(rounds) do |round|
      if block_given? 
        break if yield
      end
      puts "\nRound #{round}:"    
      @players.sort.each do |player|
        StudioGame::GameTurn.take_turn(player)
        puts player
      end
    end
  end
end


if __FILE__ == $0
  new_game = StudioGame::Game.new("ohhh_dat_game")

  player1 = StudioGame::Player.new("moe", 100)
  new_game.add_player(player1)
  puts player1

  new_game.play(10)
  
end
end