require_relative "treasure_trove"
require_relative "playable" 

module StudioGame
class Player
  include Playable
  
  attr_accessor :health
  attr_reader :name
  
  def initialize(name, health = 100)
    @name = name.capitalize
    @health = health
    @found_treasures = Hash.new(0) 
  end
  
  def self.from_csv(file)
    name, health = file.split(",")
    StudioGame::Player.new(name, Integer(health))
  end
  
  def found_treasure(treasure)
    @found_treasures[treasure.name] += treasure.points
    puts "#{@name} found a #{treasure.name} worth #{treasure.points} points."
    puts "#{@name}'s treasures: #{@found_treasures}"
    
  end
  
  def points
    @found_treasures.values.reduce(0, :+)
  end
  
  def each_treasure
    @found_treasures.each do |name, points|
      treasure = StudioGame::Treasure.new(name, points)
      yield treasure
    end
  end
  
  def to_s
    "I'm #{@name} with a health = #{@health}, points = #{points}, and score = #{score}."
  end 
  
  def name= (new_name)
    @name = new_name.capitalize
  end
end
end


if __FILE__ == $0
  player = StudioGame::Player.new("moe")
  puts player.name
  puts player.health
  player.w00t
  puts player.health
  player.blam
  puts player.health
  puts player
  puts player.strong? 
end